@@ -1,4 +1,4 @@
-;;; deb-view.el --- view Debian package files with tar-mode
+;;; deb-view.el --- view Debian package files with tar-mode. -*- lexical-binding:nil -*-
 
 ;; Copyright (C) 1998 Rick Macdonald <rickmacd@shaw.ca>
 ;; Copyright (C) 2003, 2004, 2005, 2009 Peter S Galbraith <psg@debian.org>
@@ -8,20 +8,18 @@
 
 ;; This file is not part of GNU Emacs.
 
-;; deb-view is free software; you can redistribute it and/or modify
+;; deb-view.el is free software: you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 2, or (at your option)
-;; any later version.
+;; the Free Software Foundation, either version 2 of the License, or
+;; (at your option) any later version.
 
-;; deb-view is distributed in the hope that it will be useful,
+;; deb-view.el is distributed in the hope that it will be useful,
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;; GNU General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with deb-view; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; along with GNU Emacs.  If not, see <https://www.gnu.org/licenses/>.
 
 ;;; Commentary:
 
@@ -157,7 +155,7 @@
 
 
 ;;; History:
-;; 
+;;
 
 ;; 1.3  - modified logic that determines old or new style Debian packages.
 ;;        On systems where the file command recognizes debian files, it
@@ -231,6 +229,9 @@
 
 ;;; Code:
 
+(require 'tar-mode)
+(require 'dired)
+
 (defgroup deb-view nil
   "View Debian package files with tar-mode"
   :group 'tools
@@ -253,7 +254,7 @@ See also the variable deb-find-directory."
   :group 'deb-view
   :type '(radio (const "find") (const "locate")))
 
-(defcustom deb-find-directory "/usr/local/src/debian"
+(defcustom deb-find-directory "/var/cache/apt/archives"
   "Directory to run find in when deb-find-method is \"find\"."
   :group 'deb-view
   :type 'directory)
@@ -272,7 +273,7 @@ See also the variable deb-find-directory."
 (define-key debview-mode-map "u"    'undefined)
 (define-key debview-mode-map "x"    'undefined)
 (define-key debview-mode-map ""   'undefined)
-             
+
 (define-key debview-mode-map "?"    'deb-view-help)
 (define-key debview-mode-map "q"    'deb-view-dired-view-cleanup)
 (define-key debview-mode-map "N"    'deb-view-tar-man)
@@ -296,12 +297,7 @@ See also the variable deb-find-directory."
   "The file name being processed by `deb-view'.")
 
 ;; You might not like the key bindings that I chose:
-(if (featurep 'dired)
-    (define-key dired-mode-map "\C-d" 'deb-view-dired-view)
-  (add-hook
-   'dired-load-hook
-   (function (lambda ()
-               (define-key dired-mode-map "\C-d" 'deb-view-dired-view)))))
+(define-key dired-mode-map "\C-d" 'deb-view-dired-view)
 
 ;;;###autoload
 (defun deb-view-dired-view ()
@@ -323,11 +319,6 @@ In dired, press ^d on the dired line of the .deb file to view.
 Or, execute: ESCAPE x deb-view RETURN, and enter the .deb file name
 at the prompt."
   (interactive "fdeb file to view: ")
-  (if (and (or (string-match "Lucid" emacs-version)
- 	       (string-match "XEmacs" emacs-version))
- 	   (>= emacs-major-version 21))
-      (require 'view-less)
-    (require 'view))
   (require 'view)
   (if (< (nth 1 (file-attributes debfile)) 0)
       (progn
@@ -362,11 +353,9 @@ at the prompt."
     ;; info
     (setq file-buffer (get-buffer-create " *file-data*"))
     (setq new-archive-format
-          (save-excursion
-            (set-buffer file-buffer)
+          (with-current-buffer file-buffer
             (erase-buffer)
-            (call-process shell-file-name nil t nil shell-command-switch
-                          (concat "file " debfile))
+            (call-process "file" nil '(t t) debfile)
             (goto-char 1)
             (if (string-match "archive" (buffer-string))
                 t
@@ -379,14 +368,14 @@ at the prompt."
     (cond
      (new-archive-format
       ;; New deb format (archive)
-      (call-process shell-file-name nil t nil shell-command-switch
-                    (concat "dpkg-deb --ctrl-tarfile " debfile))
+      (call-process "dpkg-deb" nil '(t t) nil "--ctrl-tarfile" debfile)
       (goto-char 1)
       (setq buffer-file-name (concat deb-view-file-name "-INFO"))
       (if (fboundp 'set-buffer-multibyte) (set-buffer-multibyte nil))
       (debview-mode)
       ;; Turn off view-mode in this buffer:
-      (make-variable-buffer-local 'view-mode-hook)
+      (make-local-variable 'view-mode-hook)
+      (make-local-variable 'view-exit-action)
       (add-hook
        'view-mode-hook
        (function (lambda ()
@@ -398,8 +387,7 @@ at the prompt."
      (t
       ;; Old deb format
       (message "deb-view old dpkg binary format")
-      (call-process shell-file-name nil t nil shell-command-switch
-                    (concat "dpkg-deb -I " debfile))
+      (call-process "dpkg-deb" nil '(t t) nil "-I"  debfile)
       (setq buffer-read-only t)
       (set-buffer-modified-p nil)
       (goto-char 1)
@@ -423,7 +411,7 @@ at the prompt."
         (goto-char (point-max))
         (when (search-backward "is not a valid archive" nil t)
           (kill-buffer data-buffer)
-          (kill-buffer info-buffer)        
+          (kill-buffer info-buffer)
           (error "%s: Not a valid package file" deb-view-buffer-name))
         (call-process-region (point-min) (point-max) "gzip" t t nil "-cd"))
        ((and (goto-char 1)(re-search-forward "data.tar.bz2" nil t))
@@ -432,21 +420,29 @@ at the prompt."
         (goto-char (point-max))
         (when (search-backward "is not a valid archive" nil t)
           (kill-buffer data-buffer)
-          (kill-buffer info-buffer)        
+          (kill-buffer info-buffer)
           (error "%s: Not a valid package file" deb-view-buffer-name))
         (call-process-region (point-min) (point-max) "bzip2" t t nil "-cd"))
+       ((and (goto-char 1)(re-search-forward "data.tar.zst" nil t))
+        (erase-buffer)
+        (call-process "ar" nil '(t t) nil "-p" debfile "data.tar.zst")
+        (goto-char (point-max))
+        (when (search-backward "is not a valid archive" nil t)
+          (kill-buffer data-buffer)
+          (kill-buffer info-buffer)
+          (error "%s: Not a valid package file" deb-view-buffer-name))
+        (call-process-region (point-min) (point-max) "zstd" t t nil "-cd"))
        ((and (goto-char 1)(re-search-forward "data.tar.xz" nil t))
         (erase-buffer)
         (call-process "ar" nil '(t t) nil "-p" debfile "data.tar.xz")
         (goto-char (point-max))
         (when (search-backward "is not a valid archive" nil t)
           (kill-buffer data-buffer)
-          (kill-buffer info-buffer)        
+          (kill-buffer info-buffer)
           (error "%s: Not a valid package file" deb-view-buffer-name))
         (call-process-region (point-min) (point-max) "xz" t t nil "-cd"))))
-     (t      
-      (call-process shell-file-name nil t nil shell-command-switch
-                    (concat "dpkg-deb --fsys-tarfile " debfile))))
+     (t
+      (call-process "dpkg-deb" '(t t) nil "--fsys-tarfile " debfile)))
     (goto-char 1)
     (setq buffer-file-name (concat deb-view-file-name "-DATA"))
     (if (fboundp 'set-buffer-multibyte) (set-buffer-multibyte nil))
@@ -495,9 +491,9 @@ output in a buffer.  See also the variable deb-find-directory.
 This command uses a special history list, so you can
 easily repeat a `deb-find' command."
   (interactive)
-  (require 'compile)
+  (eval-and-compile (require 'compile))
   (let* ((deb-file-string (read-from-minibuffer "deb file to find: "
-                                         nil nil nil 'deb-find-history))
+						nil nil nil 'deb-find-history))
          (output-buffer-name "*deb-find*")
          (command (cond ((string-equal deb-find-method "locate")
                          (concat "locate '" deb-file-string
@@ -507,9 +503,9 @@ easily repeat a `deb-find' command."
                                  deb-file-string "' | egrep '\.deb$'"))
                         (t
                          (concat deb-find-method " '" deb-file-string "'")))))
-    (compile-internal command "Not applicable in deb-find" "deb-find" nil nil
-                      (function (lambda (mode) output-buffer-name)))
+    (compilation-start command nil (lambda (mode) output-buffer-name))
     (switch-to-buffer-other-window output-buffer-name)
+    (make-local-variable 'deb-view-find-minor-mode-map)
     (setq deb-view-find-minor-mode-map
           (copy-keymap compilation-minor-mode-map))
     (use-local-map deb-view-find-minor-mode-map)
@@ -523,7 +519,7 @@ easily repeat a `deb-find' command."
     (define-key deb-view-find-minor-mode-map "\M-p" 'undefined)
     (define-key deb-view-find-minor-mode-map "\M-{" 'undefined)
     (define-key deb-view-find-minor-mode-map "\M-}" 'undefined)
-    (beginning-of-buffer)
+    (goto-char (point-min))
     (message "deb-view: ? for help. q to quit.")))
 
 
@@ -536,7 +532,7 @@ easily repeat a `deb-find' command."
   "Return string describing the version of `deb-view'.
 When called interactively, displays the version."
   (interactive)
-  (if (interactive-p)
+  (if (called-interactively-p 'interactive)
       (message "deb-view version %s" (deb-view-version))
     deb-view-version))
 
@@ -548,8 +544,7 @@ When called interactively, displays the version."
          (debfile (substring bufname 0 (- (length bufname) 5)))
          (info-buffer (get-buffer (concat debfile "-INFO")))
          (data-buffer (get-buffer (concat debfile "-DATA")))
-         (ddir-buffer (save-excursion
-                        (set-buffer quit-buffer)
+         (ddir-buffer (with-current-buffer quit-buffer
                         deb-view-dired-view-return-buffer)))
     (delete-other-windows)
     (and (buffer-live-p info-buffer)
@@ -572,10 +567,9 @@ C-c C-c - view the deb file on this line with deb-view.
 mouse-2 - view the deb file on this line with deb-view.
 ? - show deb-find-help.
 q - quit deb-find.")
-    (save-excursion
-      (set-buffer standard-output)
+    (with-current-buffer standard-output
       (help-mode))
-    (print-help-return-message)))
+    (help-print-return-message)))
 
 (defun deb-view-help ()
   "Show help information for `deb-view'."
@@ -608,15 +602,14 @@ when deb-view is loaded.
 To view files not supported by deb-view, such as graphics, use the
 copy command in tar-mode (\"c\") to copy the file to a temp directory.
 You can then do what you want to the file.")
-    (save-excursion
-      (set-buffer standard-output)
+    (with-current-buffer standard-output
       (help-mode))
-    (print-help-return-message)))
+    (help-print-return-message)))
 
 (defun deb-view-tar-man ()
   "*In Tar mode, view the tar file entry on this line as a man page."
   (interactive)
-  (require 'man)
+  (eval-and-compile (require 'man))
   (let ((auto-mode-alist
          (append '(("\\.gz$" . deb-view-tar-uncompress-while-visiting)
                    ("\\.Z$"  . deb-view-tar-uncompress-while-visiting)
@@ -651,7 +644,9 @@ If the file is from the INFO buffer, then open in the other (larger) window."
                    ("\\.Z$"  . deb-view-tar-uncompress-while-visiting)
                    ) auto-mode-alist)))
     (if (string-match "INFO$" buffer-file-name)
-        (tar-extract-other-window)
+        (progn
+          (tar-extract-other-window)
+          (view-buffer (current-buffer) 'kill-buffer-if-not-modified))
       (tar-extract 'view))))
 
 (defun deb-view-tar-w3 ()
